@@ -178,17 +178,41 @@ func (s *ExternalDiffSystem) runDiffCommand(destAbsPath, targetAbsPath AbsPath)
 		Destination: string(destAbsPath),
 		Target:      string(targetAbsPath),
 	}
+
 	args := make([]string, 0, len(s.args))
+	// Work around a regression introduced in 2.1.5
+	// (https://github.com/twpayne/chezmoi/pull/1328) in a user-friendly way.
+	//
+	// Prior to #1328, the diff.args config option was prepended to the default
+	// order of files to the diff command. Post #1328, the diff.args config
+	// option replaced all arguments to the diff command.
+	//
+	// Work around this by looking for any templates in diff.args. An arg is
+	// considered a template if, after execution as as template, it is not equal
+	// to the original arg.
+	anyTemplateArgs := false
 	for i, arg := range s.args {
 		tmpl, err := template.New("diff.args[" + strconv.Itoa(i) + "]").Parse(arg)
 		if err != nil {
 			return err
 		}
+
 		var sb strings.Builder
 		if err := tmpl.Execute(&sb, templateData); err != nil {
 			return err
 		}
 		args = append(args, sb.String())
+
+		// Detect template arguments.
+		if arg != sb.String() {
+			anyTemplateArgs = true
+		}
+	}
+
+	// If there are no template arguments, then append the destination and
+	// target paths as prior to #1328.
+	if !anyTemplateArgs {
+		args = append(args, templateData.Destination, templateData.Target)
 	}
 
 	//nolint:gosec
