@@ -265,10 +265,6 @@ func newConfig(options ...configOption) (*Config, error) {
 			recursive: true,
 		},
 		Diff: diffCmdConfig{
-			Args: []string{
-				"{{ .Destination }}",
-				"{{ .Target }}",
-			},
 			Exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 		},
@@ -284,11 +280,6 @@ func newConfig(options ...configOption) (*Config, error) {
 		},
 		Merge: mergeCmdConfig{
 			Command: "vimdiff",
-			Args: []string{
-				"{{ .Destination }}",
-				"{{ .Source }}",
-				"{{ .Target }}",
-			},
 		},
 
 		// Command configurations, not settable in the config file.
@@ -390,6 +381,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"onepassword":              c.onepasswordTemplateFunc,
 		"onepasswordDetailsFields": c.onepasswordDetailsFieldsTemplateFunc,
 		"onepasswordDocument":      c.onepasswordDocumentTemplateFunc,
+		"onepasswordItemFields":    c.onepasswordItemFieldsTemplateFunc,
 		"output":                   c.outputTemplateFunc,
 		"pass":                     c.passTemplateFunc,
 		"passRaw":                  c.passRawTemplateFunc,
@@ -1271,6 +1263,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	log.Debug().
 		Object("version", c.versionInfo).
 		Strs("args", args).
+		Str("goVersion", runtime.Version()).
 		Msg("persistentPreRunRootE")
 
 	c.baseSystem = chezmoi.NewRealSystem(c.fileSystem,
